Periodic tubes

## 3.2 Periodic tubes

Periodic tubes are constructed using a user defined number of unit cells in the z direction. The number of unit cells can also be found in the Calculations–Input options.

The nanotube will be associated with a periodic length which can be found in the Information options tab. This will be required by simulation software if the nanotube is to be used in a periodic simulation.